#define ONFRONTCONNECTED 0
#define ONFRONTDISCONNECTED 1
#define ONRSPAUTHENTICATE 2
#define ONRSPSUBMITUSERSYSTEMINFO 3
#define ONRSPUSERLOGIN 4
#define ONRSPUSERPASSWORDUPDATE 5
#define ONRSPERRORORDERINSERT 6
#define ONRSPORDERACTION 7
#define ONRSPERROREXERCISEORDERINSERT 8
#define ONRSPEXERCISEORDERACTION 9
#define ONRSPERRORLOCKINSERT 10
#define ONRSPFORQUOTEINSERT 11
#define ONRSPERRORCOMBACTIONINSERT 12
#define ONRSPQUERYMAXORDERVOLUME 13
#define ONRSPQRYLOCKVOLUME 14
#define ONRSPQUERYEXERCISEVOLUME 15
#define ONRSPQRYCOMBVOLUME 16
#define ONRSPQRYPOSITION 17
#define ONRSPQRYTRADINGACCOUNT 18
#define ONRSPQRYORDER 19
#define ONRSPQRYTRADE 20
#define ONRSPQRYEXERCISE 21
#define ONRSPQRYLOCK 22
#define ONRSPQRYCOMBACTION 23
#define ONRSPQRYPOSITIONCOMBINEDETAIL 24
#define ONRSPQRYINSTRUMENT 25
#define ONRSPQRYCOVEREDSHORT 26
#define ONRSPQRYEXERCISEASSIGN 27
#define ONRSPTRANSFER 28
#define ONRSPQRYTRANSFER 29
#define ONRSPQUERYBANKBALANCE 30
#define ONRSPQUERYBANKACCOUNT 31
#define ONRSPMULTICENTREFUNDTRANS 32
#define ONRSPQUERYBILLCONTENT 33
#define ONRSPBILLCONFIRM 34
#define ONRSPQRYMARGIN 35
#define ONRSPQRYCOMMISSION 36
#define ONRSPQRYPOSITIONDETAIL 37
#define ONRSPQRYEXCHANGERATE 38
#define ONRSPQRYSYSCONFIG 39
#define ONRSPQRYDEPTHMARKETDATA 40
#define ONRSPFUNDTRANS 41
#define ONRSPQRYFUNDTRANS 42
#define ONRSPQRYCLIENTNOTICE 43
#define ONRSPQRYOPTUNDERLY 44
#define ONRSPQRYSECUDEPTHMARKET 45
#define ONRSPQRYHISTORDER 46
#define ONRSPQRYHISTTRADE 47
#define ONRTNTRADE 48
#define ONRTNORDER 49
#define ONRTNEXERCISE 50
#define ONRTNCOMBACTION 51
#define ONRTNLOCK 52
#define ONERRRTNORDERACTION 53
#define ONRTNCLIENTNOTICE 54
