HS_OT_CallOptions = 'C'
HS_OT_PutOptions = 'P'
HS_American_Options = 'A'
HS_European_Options = 'E'
HS_EI_SSE = "1"
HS_EI_SZSE = "2"
HS_EI_CZCE = "F1"
HS_EI_DCE = "F2"
HS_EI_SHFE = "F3"
HS_EI_CFFEX = "F4"
HS_EI_INE = "F5"
HS_ET_Abandon = '0'
HS_ET_Exec = '1'
HS_CSI_CNSJC = "CNSJC"
HS_CSI_PXSJC = "PXSJC"
HS_CSI_PNSJC = "PNSJC"
HS_CSI_CXSJC = "CXSJC"
HS_CSI_KS = "KS"
HS_CSI_KKS = "KKS"
HS_CSI_ZBD = "ZBD"
HS_CSI_ZXJ = "ZXJ"
HS_DC_Buy = '1'
HS_DC_Sell = '2'
HS_DC_Loan = 'F'
HS_DC_Borrow = 'G'
HS_OD_Buy = 1
HS_OD_Sell = 2
HS_OD_Apply = 3
HS_OD_MarthSecu = 4
HS_OD_BondConv = 5
HS_OD_BondCall = 6
HS_OD_PledgeIn = 7
HS_OD_PledgeOut = 8
HS_OD_Repos = 9
HS_OD_ReverseRepos = 10
HS_OD_EtfSubs = 11
HS_OD_EtfPur = 12
HS_OD_EtfRed = 13
HS_OD_BondCallCan = 14
HS_OD_LofSubs = 16
HS_OD_LofPur = 17
HS_OD_LofRed = 18
HS_OD_LofTrams = 19
HS_OD_FundSplit = 20
HS_OD_FundMerger = 21
HS_OD_FundConv = 22
HS_OD_CurrFundPur = 23
HS_OD_CurrFundRed = 24
HS_OD_CreditBuy = 33
HS_OD_CreditSell = 34
HS_OD_CollateralIn = 35
HS_OD_CollateralOut = 36
HS_OD_MarginBuy = 37
HS_OD_ShortSell = 38
HS_OD_SellRepay = 39
HS_OD_BuyRepay = 40
HS_OD_HoldRepay = 41
HS_OF_Open = '1'
HS_OF_Close = '2'
HS_OF_Delivery = '3'
HS_OF_CloseToday = '4'
HS_OF_CloseSingle = '6'
HS_CD_Comb = '1'
HS_CD_UnComb = '2'
HS_PT_Right = '0'
HS_PT_Voluntary = '1'
HS_PT_Covered = '2'
HS_LT_Lock = '1'
HS_LT_Unlock = '2'
HS_OS_NotReported = '0'
HS_OS_ToBeReported = '1'
HS_OS_Reported = '2'
HS_OS_ReportedToBeCancel = '3'
HS_OS_PartsTradedToBeCancel = '4'
HS_OS_CanceledWithPartsTraded = '5'
HS_OS_Canceled = '6'
HS_OS_PartsTraded = '7'
HS_OS_Traded = '8'
HS_OS_Abandoned = '9'
HS_OS_CancelFailed = 'D'
HS_OS_Confirmed = 'V'
HS_OS_ToBeConfirmed = 'W'
HS_OSRC_Personal = '0'
HS_OSRC_Exchange = '1'
HS_OSRC_Member = '2'
HS_OSRC_Organization = '3'
HS_OSRC_Proprietary = '4'
HS_OSRC_MobileServiceProvider = '5'
HS_TT_BankToBroker = '1'
HS_TT_BrokerToBank = '2'
HS_TSRC_Broker = '0'
HS_TSRC_Bank = '1'
HS_TSRC_Each = '2'
HS_TSRC_Third = '3'
HS_TS_NotReported = '0'
HS_TS_Reported = '1'
HS_TS_Success = '2'
HS_TS_Abandoned = '3'
HS_TS_ReportedToBeCancel = '4'
HS_TS_Canceled = '5'
HS_TS_PendingReversal = '7'
HS_TS_Reversal = '8'
HS_TS_ToBeReported = 'A'
HS_TS_Reporting = 'P'
HS_TS_Confirmed = 'Q'
HS_TS_PendingConfirm = 'x'
HS_HT_Speculation = '0'
HS_HT_Hedge = '1'
HS_HT_Arbitrage = '2'
HS_HT_MarketMaker = '3'
HS_HT_Covered = '4'
HS_BCF_NO = '0'
HS_BCF_YES = '1'
HS_BCFD_NO = '0'
HS_BCFD_YES = '1'
HS_IT_Init = 'S'
HS_IT_CallAuction = 'C'
HS_IT_Trinding = 'T'
HS_IT_Pause = 'B'
HS_IT_Close = 'E'
HS_IT_ClosingCallAuction = 'U'
HS_IT_Fusing = 'V'
HS_IT_Halt = 'P'
HS_IT_HaltAllDay = '1'
HS_IT_FuseToCallAuction = 'M'
HS_IT_FuseToClose = 'N'
HS_IT_AfterCloseTrade = 'A'
HS_OR_NoLimitOpen = '0'
HS_OR_LimitCoveredOpen = '1'
HS_OR_LimitSellOpen = '2'
HS_OR_LimitSellAndCovOpen = '3'
HS_OR_LimitBidOpen = '4'
HS_OR_LimitBidAndCovOpen = '5'
HS_OR_LimitBidAndSellOpen = '6'
HS_OR_LimitBidAndSellAndCovOpen = '7'
HS_MMSA_NO = '0'
HS_MMSA_YES = '1'
HS_FCR_NotForceClose = '0'
HS_FCR_LackDeposit = '1'
HS_FCR_ClientOverPositionLimit = '2'
HS_FCR_MemberOverPositionLimit = '3'
HS_FCR_NotMultiple = '4'
HS_FCR_Violation = '5'
HS_FCR_Other = '6'
HS_TF_No = '0'
HS_TF_Yes = '1'
HS_SOF_Normal = '0'
HS_SOF_Swap = '1'
HS_PWDT_Fund = '1'
HS_PWDT_Trade = '2'
HS_CT_Limit = 1
HS_CT_LimitFOK = 2
HS_CT_LimitFAK = 3
HS_CT_LimitStopLoss = 4
HS_CT_LimitStopProfit = 5
HS_CT_Market = 6
HS_CT_MarketFOK = 7
HS_CT_MarketFAK = 8
HS_CT_MarketFAKV = 9
HS_CT_MarketStopLoss = 10
HS_CT_MarketStopProfit = 11
HS_CT_MarketToLimit = 12
HS_CT_Market5FAK = 13
HS_CT_Market5ToLimit = 14
HS_CT_Market1ToLimit = 15
HS_CT_Market1FAK = 16
HS_CT_Market1FOK = 17
HS_CT_MarketSelfToLimit = 18
HS_CT_CounterPartyBest = 19
HS_CT_LimitFAKV = 20
HS_CT_LimitPFP = 21
HS_SET_UnKnown = '0'
HS_SET_Stock = '1'
HS_SET_Index = '2'
HS_SET_Fund = '3'
HS_SET_Bond = '4'
HS_SET_Option = '5'
HS_SET_ETFOption = '6'
HS_ORT_Market = '1'
HS_ORT_Limit = '2'
HS_ORT_MarketSelf = 'U'
HS_TRD_Inside = 'S'
HS_TRD_Outside = 'B'
HS_TRD_UnKnown = 'N'
HS_TRD_Cancel = '4'
HS_TRD_Execute = 'F'
HS_TRANS_All = '0'
HS_TRANS_Trade = '1'
HS_TRANS_Entrust = '2'
HS_PTYPE_Futures = '1'
HS_PTYPE_OptFutu = '2'
HS_PTYPE_Combination = '3'
HS_PTYPE_Spot = '4'
HS_PTYPE_FutuToSpot = '5'
HS_PTYPE_Securities = '6'
HS_PTYPE_OptStock = '7'
HS_CID_CNY = '0'
HS_CID_USD = '1'
HS_CID_HKD = '2'
HS_CF_NO = '0'
HS_CF_YES = '1'
HS_COMBT_PT = '0'
HS_COMBT_KQ = '1'
HS_COMBT_KPZ = '2'
HS_RL_Default = '0'
HS_RL_Keep = '1'
HS_RL_Cautions = '2'
HS_RL_Steady = '3'
HS_RL_Active = '4'
HS_RL_Growth = '6'
HS_RL_Profession = '99'
HS_RL_Diy = '100'
HS_AT_Investor = '1'
HS_AT_OperatorRelay = '2'
HS_AT_InvestorRelay = '3'
HS_AT_UnKnown = '0'
HS_TT_Common = '0'
HS_TT_OptionsExecution = '1'
HS_TT_OTC = '2'
HS_TT_EFPDerived = '3'
HS_TT_CombinationDerived = '4'
HS_TD_In = '0'
HS_TD_Out = '1'
HS_ST_Stock = "0"
HS_ST_Fund = "1"
HS_ST_MarthSecu = "3"
HS_ST_Apply = "4"
HS_ST_RegDebt = "9"
HS_ST_FundAppRed = "A"
HS_ST_LofFund = "L"
HS_ST_EtfFund = "T"
HS_ST_EtfAppRed = "N"
HS_ST_Gem = "c"
HS_ST_Star = "e"
HS_ST_StarCdr = "g"
HS_ST_RegGem = "p"
HS_ST_RegGemCdr = "q"
HS_SST_PublicPreferStock = "01"
HS_SST_NonPublicPreferStock = "02"
HS_SST_MarketValueApply = "41"
HS_SST_BondCreditApply = "G1"
HS_CGP_Common = '1'
HS_CGP_Special = '2'
HS_TDS_Traded = '0'
HS_TDS_Abandoned = '2'
HS_TDS_Confirmed = '4'
HS_ES_BothForbid = '0'
HS_ES_BothAllow = '1'
HS_ES_OnlyPurchase = '2'
HS_ES_OnlyRedeem = '3'
HS_ET_SingelExchEtf = '1'
HS_ET_CrossBorderEtf = '2'
HS_ET_CrossExchEtf = '3'
HS_ET_CurrencyEtf = '4'
HS_ET_PhysicalBondEtf = '5'
HS_ET_CommodityEtf = '6'
HS_ET_CashBondEtf = '7'
HS_COS_Normal = '0'
HS_COS_Pause = '1'
HS_COS_Cancel = '2'
HS_CRT_MarginBuy = '1'
HS_CRT_ShortSell = '2'
HS_CRT_MarginBuyFine = '3'
HS_CRT_ShortSellFine = '4'
HS_CRT_SpeMarginBuy = '5'
HS_CRT_SpeShortSell = '6'
HS_CRT_SpeMarginBuyFine = '7'
HS_CRT_SpeShortSellFine = '8'
HS_COT_MarginBuy = '0'
HS_COT_ShortSell = '1'
HS_COT_OtherDebit = '2'
HS_COS_Public = '0'
HS_COS_Special = '1'
HS_OP_SecuAfof = 2
HS_OP_SecuCbp = 3
HS_OP_SecuHk = 4
HS_OP_Crdt = 5
HS_OP_CrdtAfof = 6
HS_OP_CrdtCbp = 7
HS_BF_FundTrans = 2034
HS_BF_StockTrans = 3005
HS_BF_SellRepay = 31011
HS_BF_SloCashRepay = 31107
HS_BF_CompactApply = 31118
HS_OCR_OrderInserted = '0'
HS_OCR_OrderReported = '1'
HS_OCR_OrderConfirmed = '2'
HS_OCR_OrderTraded = '3'
HS_OCR_OrderAbandoned = '4'
HS_OCR_CancelInserted = '5'
HS_OCR_CancelReported = '6'
HS_OCR_CancelConfirmed = '7'
HS_OCR_CancelFailed = '8'
HS_TERT_RESTART = 0
HS_TERT_RESUME = 1
HS_TERT_QUICK = 2
