void processFrontConnected(Task *task);

void processFrontDisconnected(Task *task);

void processRspDepthMarketDataSubscribe(Task *task);

void processRspDepthMarketDataCancel(Task *task);

void processRtnDepthMarketData(Task *task);

